AgglomerativeClustering

Struct AgglomerativeClustering 

pub struct AgglomerativeClustering { /* private fields */ }
Agglomerative (bottom-up) hierarchical clustering.

Builds a tree of clusters (dendrogram) by iteratively merging closest clusters using various linkage methods.

Algorithm

  1. Start with each point as its own cluster
  2. Repeat until reaching n_clusters:
    • Find two closest clusters using linkage method
    • Merge them
    • Update distance matrix
  3. Return cluster labels

Examples

use aprender::prelude::*;

let data = Matrix::from_vec(6, 2, vec![
    1.0, 1.0, 1.1, 1.0, 1.0, 1.1,
    5.0, 5.0, 5.1, 5.0, 5.0, 5.1,
]).expect("Valid matrix dimensions and data length");

let mut hc = AgglomerativeClustering::new(2, Linkage::Average);
hc.fit(&data).expect("Fit succeeds with valid data");

let labels = hc.predict(&data);
assert_eq!(labels.len(), 6);

Performance

  • Time complexity: O(n³) for naive implementation
  • Space complexity: O(n²) for distance matrix

Implementations

Source

impl AgglomerativeClustering

pub fn new(n_clusters: usize, linkage: Linkage) -> Self

Create new AgglomerativeClustering with target number of clusters and linkage method.

pub fn n_clusters(&self) -> usize

Get target number of clusters.

pub fn linkage(&self) -> Linkage

Get linkage method.

pub fn is_fitted(&self) -> bool

Check if model has been fitted.

pub fn labels(&self) -> &Vec<usize>

Get cluster labels (panic if not fitted).

pub fn dendrogram(&self) -> &Vec<Merge>

Get dendrogram merge history (panic if not fitted).