pub enum CGBetaFormula {
FletcherReeves,
PolakRibiere,
HestenesStiefel,
}Expand description
Beta computation formula for Conjugate Gradient.
Different formulas provide different convergence properties and numerical stability characteristics.
Variants
FletcherReeves
Fletcher-Reeves: β = (g_{k+1}^T g_{k+1}) / (g_k^T g_k)
Most stable but can be slow on non-quadratic problems.
PolakRibiere
Polak-Ribière: β = g_{k+1}^T (g_{k+1} - g_k) / (g_k^T g_k)
Better performance than FR, includes automatic restart (β < 0).
HestenesStiefel
Hestenes-Stiefel: β = g_{k+1}^T (g_{k+1} - g_k) / (d_k^T (g_{k+1} - g_k))
Similar to PR but with different denominator, can be more robust.