pub struct MagnitudePruner { /* private fields */ }Expand description
Simple magnitude-based pruner.
Uses weight magnitude as importance and generates masks to achieve the target sparsity by pruning the smallest weights.
Implementations