pub struct ShellSample { /* private fields */ }Expand description
A shell command sample with execution context.
Represents a single training example for shell autocomplete, including command history, current input prefix, and working directory context.
Example
use aprender::synthetic::shell::ShellSample;
let sample = ShellSample::new("git st", "git status")
.with_history(vec!["cd project".to_string()])
.with_cwd("/home/user/project");
assert_eq!(sample.prefix(), "git st");
assert_eq!(sample.completion(), "git status");Implementations
Sourceimpl ShellSample
impl ShellSample
Sourcepub fn new(prefix: impl Into<String>, completion: impl Into<String>) -> Self
pub fn new(prefix: impl Into<String>, completion: impl Into<String>) -> Self
Create a new shell sample.
Arguments
prefix- Current partial inputcompletion- Full completed command
Sourcepub fn with_history(self, history: Vec<String>) -> Self
pub fn with_history(self, history: Vec<String>) -> Self
Add command history context.
Sourcepub fn completion(&self) -> &str
pub fn completion(&self) -> &str
Get the completion.
Sourcepub fn command_name(&self) -> Option<&str>
pub fn command_name(&self) -> Option<&str>
Extract the command name (first token).
Sourcepub fn is_valid_completion(&self) -> bool
pub fn is_valid_completion(&self) -> bool
Check if the completion starts with the prefix.