pub struct WhitespaceTokenizer;Expand description
Whitespace tokenizer that splits text on Unicode whitespace characters.
This is the simplest tokenizer, splitting on any Unicode whitespace (spaces, tabs, newlines, etc.). It preserves punctuation attached to words.
Examples
use aprender::text::{Tokenizer, tokenize::WhitespaceTokenizer};
let tokenizer = WhitespaceTokenizer::new();
// Basic tokenization
let tokens = tokenizer.tokenize("Hello, world!").expect("tokenize should succeed");
assert_eq!(tokens, vec!["Hello,", "world!"]);
// Handles multiple spaces
let tokens = tokenizer.tokenize("foo bar").expect("tokenize should succeed");
assert_eq!(tokens, vec!["foo", "bar"]);
// Handles newlines and tabs
let tokens = tokenizer.tokenize("line1\nline2\ttab").expect("tokenize should succeed");
assert_eq!(tokens, vec!["line1", "line2", "tab"]);Implementations
Sourceimpl WhitespaceTokenizer
impl WhitespaceTokenizer
Sourcepub fn new() -> WhitespaceTokenizer
pub fn new() -> WhitespaceTokenizer
Create a new whitespace tokenizer.
Examples
use aprender::text::tokenize::WhitespaceTokenizer;
let tokenizer = WhitespaceTokenizer::new();Trait Implementations
Sourceimpl Clone for WhitespaceTokenizer
impl Clone for WhitespaceTokenizer
Sourcefn clone(&self) -> WhitespaceTokenizer
fn clone(&self) -> WhitespaceTokenizer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WhitespaceTokenizer
impl Debug for WhitespaceTokenizer
Sourceimpl Default for WhitespaceTokenizer
impl Default for WhitespaceTokenizer
Sourcefn default() -> WhitespaceTokenizer
fn default() -> WhitespaceTokenizer
Returns the “default value” for a type. Read more