LinearRegression

Struct LinearRegression 

pub struct LinearRegression { /* private fields */ }
Ordinary Least Squares (OLS) linear regression.

Fits a linear model by minimizing the residual sum of squares between observed targets and predicted targets. The model equation is:

y = X β + ε

where β is the coefficient vector and ε is random error.

Solver

Uses normal equations: β = (X^T X)^-1 X^T y via Cholesky decomposition.

Examples

use aprender::prelude::*;

// Simple linear regression: y = 2x + 1
let x = Matrix::from_vec(4, 1, vec![
    1.0,
    2.0,
    3.0,
    4.0,
]).expect("Valid matrix dimensions");
let y = Vector::from_slice(&[3.0, 5.0, 7.0, 9.0]);

let mut model = LinearRegression::new();
model.fit(&x, &y).expect("Fit should succeed with valid data");

let predictions = model.predict(&x);
let r2 = model.score(&x, &y);
assert!(r2 > 0.99);

Performance

  • Time complexity: O(n²p + p³) where n = samples, p = features
  • Space complexity: O(np)

Implementations

Source

impl LinearRegression

pub fn new() -> Self

Creates a new LinearRegression with default settings.

pub fn with_intercept(self, fit_intercept: bool) -> Self

Sets whether to fit an intercept term.

pub fn coefficients(&self) -> &Vector<f32>

Returns the coefficients (excluding intercept).

Panics

Panics if model is not fitted.

pub fn intercept(&self) -> f32

Returns the intercept term.

pub fn is_fitted(&self) -> bool

Returns true if the model has been fitted.

pub fn save<P: AsRef<Path>>(&self, path: P) -> Result<(), String>

Saves the model to a binary file using bincode.

Errors

Returns an error if serialization or file writing fails.

pub fn load<P: AsRef<Path>>(path: P) -> Result<Self, String>

Loads a model from a binary file.

Errors

Returns an error if file reading or deserialization fails.

pub fn save_safetensors<P: AsRef<Path>>(&self, path: P) -> Result<(), String>

Saves the model to SafeTensors format.

SafeTensors format is compatible with:

  • HuggingFace ecosystem
  • Ollama (can convert to GGUF)
  • PyTorch, TensorFlow
  • realizar inference engine
Errors

Returns an error if:

  • Model is not fitted
  • Serialization fails
  • File writing fails
pub fn load_safetensors<P: AsRef<Path>>(path: P) -> Result<Self, String>

Loads a model from SafeTensors format.

Errors

Returns an error if:

  • File reading fails
  • SafeTensors format is invalid
  • Required tensors are missing