Proximal operators for non-smooth regularization.
A proximal operator for function g is defined as:
prox_g(v) = argmin_x { g(x) + ½‖x - v‖² }These are essential building blocks for proximal gradient methods like FISTA.
Functions
- nonnegative
- Projects onto the non-negative orthant: x ≥ 0.
- project_
box - Projects onto box constraints: lower ≤ x ≤ upper.
- project_
l2_ ball - Projects onto an L2 ball: ‖x‖₂ ≤ radius.
- soft_
threshold - Soft-thresholding operator for L1 regularization.