pub struct DampedNewton { /* private fields */ }Expand description
Damped Newton optimizer with finite-difference Hessian approximation.
Newton’s method uses second-order information (Hessian) to find the minimum by solving the linear system: H * d = -g, where H is the Hessian and g is the gradient. The damping factor and line search ensure global convergence.
Algorithm
- Compute gradient g = ∇f(x)
- Approximate Hessian H using finite differences
- Solve H * d = -g using Cholesky decomposition
- If Hessian not positive definite, fall back to steepest descent
- Line search along d to find step size α
- Update: x_{k+1} =
x_k+ α *d_k
Parameters
max_iter: Maximum number of iterations- tol: Convergence tolerance (gradient norm)
- epsilon: Finite difference step size for Hessian approximation (default: 1e-5)
Example
use aprender::optim::{DampedNewton, Optimizer};
use aprender::primitives::Vector;
let mut optimizer = DampedNewton::new(100, 1e-5);
// Minimize quadratic function f(x,y) = x^2 + 2y^2
let f = |x: &Vector<f32>| x[0] * x[0] + 2.0 * x[1] * x[1];
let grad = |x: &Vector<f32>| Vector::from_slice(&[2.0 * x[0], 4.0 * x[1]]);
let x0 = Vector::from_slice(&[5.0, 3.0]);
let result = optimizer.minimize(f, grad, x0);Implementations
Sourceimpl DampedNewton
impl DampedNewton